==> jc-1.4.0.tar.gz: soot/baf/internal/AbstractRefTypeInst.h <==
// public abstract class soot.baf.internal.AbstractRefTypeInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 505b6f9016f9e51a soot_baf_internal_AbstractRefTypeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_AbstractRefTypeInst_H_
#define _JC_soot_baf_internal_AbstractRefTypeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_refs	_jc_soot_baf_internal_AbstractRefTypeInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs	_jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$refs	_jc_soot_baf_internal_AbstractRefTypeInst$refs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$nonrefs	_jc_soot_baf_internal_AbstractRefTypeInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$object	_jc_soot_baf_internal_AbstractRefTypeInst$object;

typedef const struct _jc_soot_baf_internal_AbstractRefTypeInst$vmethods	_jc_soot_baf_internal_AbstractRefTypeInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractRefTypeInst$vtable	_jc_soot_baf_internal_AbstractRefTypeInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractRefTypeInst$vtype	_jc_soot_baf_internal_AbstractRefTypeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_RefType$object *);

// Virtual methods
extern struct _jc_soot_RefType$object *_jc_soot_baf_internal_AbstractRefTypeInst$method$getBaseType$b249be320d6d3409(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *);
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_AbstractRefTypeInst$method$getOpType$2611df5c7a014636(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractRefTypeInst$method$getParameters$264df409c6a640fb(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *);
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$getParameters$7ca7e2a5895cbf14(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_object *);
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$setBaseType$aec1528d245a4bf6(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_RefType$object *);
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$setOpType$96cc62a0f09a0473(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getBaseType$b249be320d6d3409;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getOpType$2611df5c7a014636;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getParameters$264df409c6a640fb;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getParameters$7ca7e2a5895cbf14;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$setBaseType$aec1528d245a4bf6;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$setOpType$96cc62a0f09a0473;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractRefTypeInst$vmethods {
	struct _jc_soot_RefType$object	*(*getBaseType$b249be320d6d3409)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *);
	struct _jc_soot_Type$object	*(*getOpType$2611df5c7a014636)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *);
	struct _jc_java_lang_String$object	*(*getParameters$264df409c6a640fb)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *);
	void	(*getParameters$7ca7e2a5895cbf14)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_object *);
	void	(*setBaseType$aec1528d245a4bf6)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_RefType$object *);
	void	(*setOpType$96cc62a0f09a0473)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_baf_internal_AbstractRefTypeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractRefTypeInst$vmethods	soot_baf_internal_AbstractRefTypeInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractRefTypeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractRefTypeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_refs {
	struct _jc_soot_Type$object	*opType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractRefTypeInst$refs {
    _jc_soot_baf_internal_AbstractRefTypeInst$sub_refs	soot_baf_internal_AbstractRefTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractRefTypeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs	soot_baf_internal_AbstractRefTypeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractRefTypeInst$object {
	_jc_soot_baf_internal_AbstractRefTypeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractRefTypeInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractRefTypeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractRefTypeInst$vtype _jc_soot_baf_internal_AbstractRefTypeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractRefTypeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractRefTypeInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractRefTypeInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/AbstractRefTypeInst.h <==
// public abstract class soot.baf.internal.AbstractRefTypeInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class 505b6f9016f9e51a soot_baf_internal_AbstractRefTypeInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractInst

#include "soot/baf/internal/AbstractInst.h"

#ifndef _JC_soot_baf_internal_AbstractRefTypeInst_H_
#define _JC_soot_baf_internal_AbstractRefTypeInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_RefType$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_refs	_jc_soot_baf_internal_AbstractRefTypeInst$sub_refs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs	_jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$refs	_jc_soot_baf_internal_AbstractRefTypeInst$refs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$nonrefs	_jc_soot_baf_internal_AbstractRefTypeInst$nonrefs;
typedef struct _jc_soot_baf_internal_AbstractRefTypeInst$object	_jc_soot_baf_internal_AbstractRefTypeInst$object;

typedef const struct _jc_soot_baf_internal_AbstractRefTypeInst$vmethods	_jc_soot_baf_internal_AbstractRefTypeInst$vmethods;
typedef const struct _jc_soot_baf_internal_AbstractRefTypeInst$vtable	_jc_soot_baf_internal_AbstractRefTypeInst$vtable;
typedef const struct _jc_soot_baf_internal_AbstractRefTypeInst$vtype	_jc_soot_baf_internal_AbstractRefTypeInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$_init$b4480ebfa3c48018(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_RefType$object *_jc_soot_baf_internal_AbstractRefTypeInst$method$getBaseType$b249be320d6d3409(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_baf_internal_AbstractRefTypeInst$method$getOpType$2611df5c7a014636(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_AbstractRefTypeInst$method$getParameters$264df409c6a640fb(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$getParameters$7ca7e2a5895cbf14(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$setBaseType$aec1528d245a4bf6(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_AbstractRefTypeInst$method$setOpType$96cc62a0f09a0473(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getBaseType$b249be320d6d3409;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getOpType$2611df5c7a014636;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getParameters$264df409c6a640fb;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$getParameters$7ca7e2a5895cbf14;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$setBaseType$aec1528d245a4bf6;
extern _jc_method _jc_soot_baf_internal_AbstractRefTypeInst$method_info$setOpType$96cc62a0f09a0473;

// Virtual methods structure
struct _jc_soot_baf_internal_AbstractRefTypeInst$vmethods {
	struct _jc_soot_RefType$object	*(*getBaseType$b249be320d6d3409)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getOpType$2611df5c7a014636)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getParameters$264df409c6a640fb)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *) _JC_JCNI_ATTR;
	void	(*getParameters$7ca7e2a5895cbf14)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setBaseType$aec1528d245a4bf6)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_RefType$object *) _JC_JCNI_ATTR;
	void	(*setOpType$96cc62a0f09a0473)(_jc_env *, struct _jc_soot_baf_internal_AbstractRefTypeInst$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_AbstractRefTypeInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractRefTypeInst$vmethods	soot_baf_internal_AbstractRefTypeInst;
};

// Vtype
struct _jc_soot_baf_internal_AbstractRefTypeInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_AbstractRefTypeInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_refs {
	struct _jc_soot_Type$object	*opType;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_AbstractRefTypeInst$refs {
    _jc_soot_baf_internal_AbstractRefTypeInst$sub_refs	soot_baf_internal_AbstractRefTypeInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_AbstractRefTypeInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractRefTypeInst$sub_nonrefs	soot_baf_internal_AbstractRefTypeInst;
};

// Object instance structure
struct _jc_soot_baf_internal_AbstractRefTypeInst$object {
	_jc_soot_baf_internal_AbstractRefTypeInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_AbstractRefTypeInst$vtype	*vtype;
	_jc_soot_baf_internal_AbstractRefTypeInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_AbstractRefTypeInst$vtype _jc_soot_baf_internal_AbstractRefTypeInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_AbstractRefTypeInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_AbstractRefTypeInst$class_object;

#endif	/* _JC_soot_baf_internal_AbstractRefTypeInst_H_ */
